@@ -6,6 +6,10 @@
  * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
  * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
  *
+ * Sonatype Nexus (TM) Open Source Version is distributed with Sencha Ext JS pursuant to a FLOSS Exception agreed upon
+ * between Sonatype, Inc. and Sencha Inc. Sencha Ext JS is licensed under GPL v3 and cannot be redistributed as part of a
+ * closed source work.
+ *
  * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
  * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
  * Eclipse Foundation. All other trademarks are the property of their respective owners.
@@ -137,7 +141,8 @@ Ext.define('NX.controller.Menu', {
         'nx-feature-menu': {
           itemclick: me.onItemClick,
           afterrender: me.onAfterRender,
-          beforecellclick: me.warnBeforeMenuSelect
+          beforecellclick: me.warnBeforeMenuSelect,
+          beforeselect: me.onBeforeSelect
         },
         'nx-main #quicksearch': {
           beforesearch: me.warnBeforeSearch
@@ -223,9 +228,14 @@ Ext.define('NX.controller.Menu', {
         path = featureMenuModel.get('path'),
         forceReselect = forceReselectOrHtmlElement,
         pathIsChanging = path !== me.currentSelectedPath,
-        isGroup = featureMenuModel.get('group');
+        isGroup = featureMenuModel.get('group'),
+        externalLink = featureMenuModel.get('hrefTarget') === '_blank',
+        separator = featureMenuModel.get('separator');
 
-    if (forceReselect || pathIsChanging || isGroup) {
+    if (externalLink || separator) {
+      return;
+    }
+    else if (forceReselect || pathIsChanging || isGroup) {
       me.currentSelectedPath = path;
 
       //<if debug>
@@ -240,6 +250,15 @@ Ext.define('NX.controller.Menu', {
     }
   },
 
+  onBeforeSelect: function(panel, featureMenuModel) {
+    var externalLink = featureMenuModel.get('hrefTarget') === '_blank',
+        separator = featureMenuModel.get('separator');
+
+    if (externalLink || separator) {
+      return false;
+    }
+  },
+
   /**
    * @private
    */
@@ -583,6 +602,8 @@ Ext.define('NX.controller.Menu', {
       { property: 'text', direction: 'ASC' }
     ]);
 
+    me.addExternalLinks();
+
     Ext.resumeLayouts(true);
   },
 
@@ -759,11 +780,11 @@ Ext.define('NX.controller.Menu', {
    */
   warnBeforeSearch: function() {
     var me = this,
-      button = me.getHeaderPanel().down('nx-header-quicksearch');
+      quickSearch = me.getHeaderPanel().down('nx-header-quicksearch');
 
     return me.warnBeforeNavigate(
       function() {
-        button.fireEvent('search', button, button.getValue());
+        quickSearch.triggerSearch();
       }
     );
   },
@@ -857,6 +878,7 @@ Ext.define('NX.controller.Menu', {
 
         // Reset the unsaved changes flag
         content.resetUnsavedChangesFlag();
+        window.dirty = [];
       }
     });
   },
@@ -868,7 +890,8 @@ Ext.define('NX.controller.Menu', {
    */
   hasDirt: function() {
     var dirty = false,
-      forms = Ext.ComponentQuery.query('form[settingsForm=true]');
+      forms = Ext.ComponentQuery.query('form[settingsForm=true]'),
+      reactDirty = window.dirty || [];
 
     // Check for dirty content
     if (forms.length !== 0) {
@@ -880,7 +903,7 @@ Ext.define('NX.controller.Menu', {
       });
     }
 
-    return dirty;
+    return dirty || reactDirty.length > 0;
   },
 
   /**
@@ -896,5 +919,32 @@ Ext.define('NX.controller.Menu', {
         return NX.I18n.get('Menu_Browser_Title');
       }
     };
+  },
+
+  addExternalLinks: function() {
+    var rootNode = this.getStore('FeatureMenu').getRootNode(),
+        clmState = NX.State.getValue('clm'),
+        showDashboardUrl = clmState && clmState.enabled && clmState.url,
+        shouldShowDashboardLink = showDashboardUrl && clmState.showLink;
+
+    if (this.mode === 'browse' && shouldShowDashboardLink) {
+      rootNode.appendChild({
+        leaf: true,
+        separator: true,
+        cls: 'separator',
+        iconCls: ' ',
+        text: ' '
+      });
+      rootNode.appendChild({
+        leaf: true,
+        qtip: NX.I18n.get('Clm_Dashboard_Description'),
+        authenticationRequired: false,
+        mode: 'browse',
+        text: NX.I18n.get('Clm_Dashboard_Link_Text'),
+        href: showDashboardUrl,
+        hrefTarget: '_blank',
+        cls: 'iq-dashboard-link'
+      });
+    }
   }
 });
