@@ -6,6 +6,10 @@
  * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
  * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
  *
+ * Sonatype Nexus (TM) Open Source Version is distributed with Sencha Ext JS pursuant to a FLOSS Exception agreed upon
+ * between Sonatype, Inc. and Sencha Inc. Sencha Ext JS is licensed under GPL v3 and cannot be redistributed as part of a
+ * closed source work.
+ *
  * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
  * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
  * Eclipse Foundation. All other trademarks are the property of their respective owners.
@@ -21,6 +25,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
   extend: 'NX.controller.Drilldown',
   requires: [
     'NX.Bookmarks',
+    'NX.Dialogs',
     'NX.Messages',
     'NX.Permissions',
     'NX.I18n',
@@ -59,7 +64,6 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     {ref: 'repositoryList', selector: 'nx-coreui-componentassettreefeature nx-coreui-browse-repository-list'},
     {ref: 'componentAssetTree', selector: 'nx-coreui-componentassettreefeature nx-coreui-component-asset-tree'},
     {ref: 'componentAssetTreePanel', selector: 'nx-coreui-componentassettreefeature nx-coreui-component-asset-tree treepanel'},
-    {ref: 'treeFilterBox', selector: 'nx-coreui-componentassettreefeature nx-searchbox'},
     {ref: 'advancedSearchLink', selector: 'nx-coreui-componentassettreefeature #nx-coreui-component-asset-tree-advanced-search'},
     {ref: 'uploadButton', selector: 'nx-coreui-componentassettreefeature button[action=upload]'},
     {ref: 'htmlViewLink', selector: 'nx-coreui-componentassettreefeature #nx-coreui-component-asset-tree-html-view'},
@@ -68,8 +72,10 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     {ref: 'componentFolderInfo', selector: 'nx-coreui-component-componentfolderinfo'},
     {ref: 'deleteComponentButton', selector: 'nx-coreui-component-componentinfo button[action=deleteComponent]'},
     {ref: 'deleteAssetButton', selector: 'nx-coreui-component-componentassetinfo button[action=deleteAsset]'},
+    {ref: 'deleteAssetFolderButton', selector: 'nx-coreui-component-componentassetinfo button[action=deleteFolder]'},
     {ref: 'deleteFolderButton', selector: 'nx-coreui-component-componentfolderinfo button[action=deleteFolder]'},
     {ref: 'analyzeApplicationButton', selector: 'nx-coreui-component-componentinfo button[action=analyzeApplication]'},
+    {ref: 'viewVulnerabilitiesButton', selector: 'nx-coreui-component-componentinfo button[action=viewVulnerabilities]'},
     {ref: 'analyzeApplicationWindow', selector: 'nx-coreui-component-analyze-window'},
     {ref: 'rootContainer', selector: 'nx-main'},
     {ref: 'treeWarning', selector: 'nx-coreui-componentassettreefeature nx-coreui-component-asset-tree #warning'}
@@ -120,35 +126,29 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
         'nx-coreui-componentassettreefeature nx-coreui-browse-repository-list': {
           beforerender: me.onBeforeRender
         },
-        'nx-coreui-componentassettreefeature nx-drilldown-item > container': {
-          beforedeactivate: me.onBeforeDeactivate
-        },
         'nx-coreui-componentassettreefeature treepanel': {
           select: me.selectNode,
-          itemkeydown: me.itemKeyDown
-        },
-        'nx-coreui-componentassettreefeature nx-searchbox': {
-          search: me.onFilterChanged,
-          searchcleared: me.onFilterChanged
-        },
+          itemkeydown: me.itemKeyDown,
+          itemexpand: me.itemExpand
+  },
         'nx-coreui-component-componentinfo button[action=deleteComponent]': {
           click: me.deleteComponent
         },
         'nx-coreui-component-componentinfo button[action=analyzeApplication]': {
           click: me.mixins.componentUtils.openAnalyzeApplicationWindow
         },
+        'nx-coreui-component-componentinfo button[action=viewVulnerabilities]': {
+          click: me.mixins.componentUtils.viewVulnerabilities
+        },
         'nx-coreui-component-componentassetinfo button[action=deleteAsset]': {
           click: me.deleteAsset
         },
+        'nx-coreui-component-componentassetinfo button[action=deleteFolder]': {
+          click: me.deleteAssetFolder
+        },
         'nx-coreui-component-componentfolderinfo button[action=deleteFolder]': {
           click: me.deleteFolder
         },
-        'nx-coreui-component-analyze-window button[action=analyze]': {
-          click: me.analyzeAsset
-        },
-        'nx-coreui-component-analyze-window combobox[name="asset"]': {
-          select: me.selectedApplicationChanged
-        },
         'nx-coreui-componentassettreefeature button[action=upload]': {
           click: me.onClickUploadButton
         },
@@ -167,6 +167,14 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
         file: 'box_front.png',
         variants: ['x16']
       },
+      'tree-component-vulnerable': {
+        file: 'box_front_error.png',
+        variants: ['x16']
+      },
+      'vulnerability': {
+        file: 'vulnerability.png',
+        variants: ['x16', 'x32']
+      },
       'tree-asset': {
         file: 'page_white_stack.png',
         variants: ['x16']
@@ -241,11 +249,9 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
   onRepositorySelection: function(model) {
     var me = this, componentAssetTreeStore = me.getStore('ComponentAssetTree');
 
-    if (!me.selectedRepository || me.selectedRepository.id !== model.id) {
-      //reset the filter
-      componentAssetTreeStore.proxy.setExtraParam('filter');
-      componentAssetTreeStore.proxy.setExtraParam('repositoryName', model.get('name'));
-    }
+    //reset the filter
+    componentAssetTreeStore.proxy.setExtraParam('filter');
+    componentAssetTreeStore.proxy.setExtraParam('repositoryName', model.get('name'));
 
     // Update HTML View link
     me.updateHtmlLink(model);
@@ -311,43 +317,8 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
   },
 
   browseNodesLoaded: function(store, node, records) {
-    var message = { type: 'warning', text: NX.I18n.get('Component_Asset_Tree_Results_Warning')};
-    if (records && records.length === NX.State.getValue('browseTreeMaxNodes') && !NX.Messages.messageExists(message)) {
-      NX.Messages.add(message);
-    }
-  },
-
-  /**
-   * @private
-   * Handle when the filter changes, so the tree will be reloaded and future node requests will contain the filter
-   * parameter
-   */
-  onFilterChanged: function(filterBox, value) {
-    var me = this,
-        componentAssetTreeStore = me.getStore('ComponentAssetTree'),
-        emptyText = me.getComponentAssetTreePanel().view.emptyText,
-        advancedSearchLink = me.getAdvancedSearchLink(),
-        treePanel = me.getComponentAssetTreePanel(),
-        url;
-
-    if (me.selectedRepository) {
-      // repository selected, filter the tree
-      if (value) {
-        url = 'browse/search=' + encodeURIComponent('keyword=' + value);
-        emptyText = emptyText.replace(/>.*</, '>' + NX.I18n.get('Component_Asset_Tree_Filtered_EmptyText_View') + '<');
-        emptyText = emptyText.replace('browse/search', url);
-
-        advancedSearchLink.setText(advancedSearchLink.initialConfig.html.replace('browse/search', url), false);
-      } else {
-        emptyText = emptyText.replace(/>.*</, '>' + NX.I18n.get('Component_Asset_Tree_EmptyText_View') + '<');
-
-        advancedSearchLink.setText(advancedSearchLink.initialConfig.html, false);
-      }
-      treePanel.view.emptyText = emptyText;
-
-      componentAssetTreeStore.proxy.setExtraParam('filter', value);
-
-      me.reloadNodes();
+    if (records && records.length === NX.State.getValue('browseTreeMaxNodes')) {
+      NX.Messages.warning(NX.I18n.get('Component_Asset_Tree_Results_Warning'));
     }
   },
 
@@ -383,7 +354,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
       return;
     }
 
-    if (rebuildingRepositories.indexOf(repositoryName) !== -1) {
+    if (rebuildingRepositories.indexOf('*') !== -1 || rebuildingRepositories.indexOf(repositoryName) !== -1) {
       warning.setTitle(NX.I18n.format('ComponentDetails_Rebuild_Warning'));
       warning.show();
     }
@@ -403,11 +374,35 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     }
   },
 
+  itemExpand: function(view) {
+    var childNodes = Ext.Array.filter(view.childNodes, function(node) {
+      return node.data.packageUrl;
+    });
+    var packageUrls = Ext.Array.map(childNodes, function(node) {
+      return node.data.packageUrl;
+    });
+    if (packageUrls.length > 0 && NX.direct.coreui_Vulnerability) {
+      NX.direct.coreui_Vulnerability.read(packageUrls, function(response) {
+        if (response.success && response.data) {
+          Ext.Array.each(view.childNodes, function(node) {
+            var report = response.data[node.data.packageUrl];
+            if (report && report.count > 0) {
+              node.set('vulnerable', true);
+              node.set('iconCls', 'nx-icon-vulnerability-x16');
+              node.commit();
+            }
+          })
+        }
+      });
+    }
+  },
+
   selectNode: function(view, node) {
     var me = this,
         componentInfoPanel,
         componentInfoPanelTitleText,
-        assetInfoPanel;
+        assetInfoPanel,
+        isFolder = !node.get('leaf');
 
     me.removeSideContent();
     me.bookmarkNode(node);
@@ -429,6 +424,8 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
           me.setComponentModel(componentModel);
          }
       });
+
+      me.handleVulnerabilitiesPanel(node, componentInfoPanel);
     }
     else if ('asset' === node.get('type')) {
       assetInfoPanel = me.getComponentAssetInfo();
@@ -439,16 +436,18 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
 
       NX.direct.coreui_Component.readAsset(node.get('assetId'), me.getCurrentRepository().get('name'), function(response) {
         if (me.isPanelVisible(assetInfoPanel) && me.isResponseSuccessful(response)) {
-          me.setInfoPanelModel(assetInfoPanel, me.getAssetModel().create(response.data));
+          me.setInfoPanelModel(assetInfoPanel, me.getAssetModel().create(response.data), isFolder);
         }
         else {
           me.maybeUnmask(assetInfoPanel);
         }
       });
+
+      me.handleVulnerabilitiesPanel(node, assetInfoPanel);
     }
     else if ('folder' === node.get('type')) {
       var folderInfoPanel = me.getComponentFolderInfo();
-      folderInfoPanel.setTitle(node.get('text'));
+      folderInfoPanel.setTitle(me.buildPathString(node));
       folderInfoPanel.setIconCls(me.mixins.componentUtils.getIconForAsset(node).get('cls'));
       folderInfoPanel.show();
 
@@ -456,11 +455,33 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
       me.getDeleteFolderButton().show();
       me.getDeleteFolderButton().enable();
       folderInfoPanel.setModel({repositoryName: me.getCurrentRepository().get('name'), folderName: node.get('text'), path: node.get('id')});
-      me.updateDeleteFolderButton(me.getCurrentRepository(), node.get('id'));
+      me.updateDeleteFolderButton(me.getDeleteFolderButton(), me.getCurrentRepository(), node.get('id'));
       me.maybeUnmask(folderInfoPanel);
     }
   },
 
+  handleVulnerabilitiesPanel: function(node, panel) {
+    var me = this;
+    if ('OSS' === NX.State.getEdition() && me.getCurrentRepository().get('type') === 'proxy' &&
+        NX.direct.coreui_Vulnerability) {
+      var packageUrl = node.get('packageUrl');
+      NX.direct.coreui_Vulnerability.read([packageUrl],
+          function(response) {
+            var vulnerabilityPanel = panel.getVulnerabilityPanel();
+            if(response.success && response.data) {
+              vulnerabilityPanel.setVisible(true);
+              var vulnReport = response.data[packageUrl];
+              me.setVulnerabilityInfo(vulnerabilityPanel, vulnReport);
+              me.updateVulnerabilitiesButton(panel, vulnReport);
+            }
+            else {
+              vulnerabilityPanel.setVisible(false);
+              me.updateVulnerabilitiesButton(panel, null);
+            }
+          });
+    }
+  },
+
   setComponentModel: function(componentModel) {
     var componentInfoPanel = this.getComponentInfo();
 
@@ -470,7 +491,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     this.setDependencySnippets(componentInfoPanel.getDependencySnippetPanel(), componentModel);
   },
 
-  setInfoPanelModel: function(assetInfoPanel, asset) {
+  setInfoPanelModel: function(assetInfoPanel, asset, isFolder) {
     var me = this,
         componentModel;
 
@@ -480,7 +501,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
         if (me.isPanelVisible(assetInfoPanel) && me.isResponseSuccessful(response)) {
           componentModel = me.getComponentModel().create(response.data);
           assetInfoPanel.setModel(asset, componentModel);
-          me.updateDeleteAssetButton(me.getCurrentRepository(), asset);
+          me.updateDeleteAssetButton(me.getCurrentRepository(), asset, isFolder);
           me.setDependencySnippets(assetInfoPanel.getDependencySnippetPanel(), componentModel, asset);
         }
       });
@@ -490,7 +511,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
       if (me.isPanelVisible(assetInfoPanel)) {
         componentModel = me.getComponentModel().create({});
         assetInfoPanel.setModel(asset, componentModel);
-        me.updateDeleteAssetButton(me.getCurrentRepository(), asset);
+        me.updateDeleteAssetButton(me.getCurrentRepository(), asset, isFolder);
         me.setDependencySnippets(assetInfoPanel.getDependencySnippetPanel(), componentModel, asset);
       }
     }
@@ -512,6 +533,25 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     }
   },
 
+  setVulnerabilityInfo: function(vulnerabilityPanel, vulnerabilityInfo) {
+    var summary = {};
+
+    if (vulnerabilityInfo) {
+        summary[NX.I18n.get('Vulnerability_Count')] = Ext.htmlEncode(vulnerabilityInfo.count);
+        summary[NX.I18n.get('Vulnerability_Ref')] = NX.util.Url.asLink(vulnerabilityInfo.reference);
+        vulnerabilityPanel.referenceLink = vulnerabilityInfo.reference;
+        if(vulnerabilityInfo.count > 0) {
+          vulnerabilityPanel.items.items[0].header.addCls('vulnerabilities');
+        } else {
+          vulnerabilityPanel.items.items[0].header.removeCls('vulnerabilities');
+        }
+    }
+    else {
+      summary[NX.I18n.get('Vulnerability_Information')] = Ext.htmlEncode(NX.I18n.get('Vulnerability_NotScanned'));
+    }
+    vulnerabilityPanel.showInfo(summary);
+  },
+
   isPanelVisible : function(panel) {
     return panel && panel.isVisible();
   },
@@ -549,7 +589,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     var path = '';
     //node.parentNode check will skip the trees root node (labeld Root and hidden)
     while (node != null && node.parentNode != null) {
-      path = node.get('text') + '/' + path;
+      path = path ? (node.get('text') + '/' + path) : node.get('text');
       node = node.parentNode;
     }
 
@@ -611,16 +651,6 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     }
   },
 
-  /**
-   * @private
-   * Clears the filter box before the view is changed
-   */
-  onBeforeDeactivate: function(oldCard) {
-    var filterBox = oldCard.down('nx-searchbox');
-
-    filterBox && filterBox.clearSearch && filterBox.clearSearch();
-  },
-
   /**
    * @private
    * Opens the Upload UI for current repository
@@ -662,7 +692,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
 
     if (uploadButton && repository) {
       if (NX.State.getValue('upload') &&
-          NX.Permissions.check('nexus:component:add') &&
+          NX.Permissions.check('nexus:component:create') &&
           repository.getData().type === 'hosted' &&
           repository.getData().versionPolicy !== 'SNAPSHOT') {
         store.load(function (store, results) {
@@ -715,12 +745,13 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
           if (Ext.isObject(response) && response.success && Ext.isArray(response.data)) {
             me.removeNodeFromTree(selectedNode);
             Ext.each(response.data, function (nodeId) {
-              var node = treePanel.getStore().findNode('id', nodeId);
+              var nodePath = nodeId.charAt(0) === '/' ? nodeId.substring(1) : nodeId;
+              var node = treePanel.getStore().findNode('id', nodePath);
               if (node) {
                 me.removeNodeFromTree(node);
               }
             });
-            NX.Messages.add({text: NX.I18n.format('ComponentDetails_Delete_Success', componentId), type: 'success'});
+            NX.Messages.success(NX.I18n.format('ComponentDetails_Delete_Success', componentId));
           }
         });
       });
@@ -750,7 +781,7 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
               selectedRecord.set('type', 'folder');
               selectedRecord.set('iconCls', me.mixins.componentUtils.getIconForAsset(selectedRecord).get('cls'));
             }
-            NX.Messages.add({text: NX.I18n.format('AssetInfo_Delete_Success', asset.get('name')), type: 'success'});
+            NX.Messages.success(NX.I18n.format('AssetInfo_Delete_Success', asset.get('name')));
           }
         });
       });
@@ -771,10 +802,33 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
           NX.I18n.get('FolderInfo_Delete_Title'),
           NX.I18n.format('FolderInfo_Delete_Text', Ext.htmlEncode(model.folderName)),
           function() {
-            NX.direct.coreui_Component.deleteFolder(model.path, model.repositoryName,
+            NX.direct.coreui_Component.deleteFolder(decodeURIComponent(model.path.replace(/\+/g, ' ')), model.repositoryName,
                 function(response) {
                   if (Ext.isObject(response) && response.success) {
-                    NX.Messages.add({text: NX.I18n.format('FolderInfo_Delete_Success'), type: 'success'});
+                    NX.Messages.success(NX.I18n.format('FolderInfo_Delete_Success'));
+                  }
+                });
+          });
+    }
+  },
+
+  /**
+   * @private
+   * Remove selected Folder.
+   */
+  deleteAssetFolder: function() {
+    var componentAssetInfo = this.getComponentAssetInfo();
+
+    if (componentAssetInfo) {
+      var asset = componentAssetInfo.assetModel;
+      NX.Dialogs.askConfirmation(
+          NX.I18n.get('FolderInfo_Delete_Title'),
+          NX.I18n.format('FolderInfo_Delete_Text', Ext.htmlEncode(asset.get('name'))),
+          function() {
+            NX.direct.coreui_Component.deleteFolder(asset.get('name'), asset.get('repositoryName'),
+                function(response) {
+                  if (Ext.isObject(response) && response.success) {
+                    NX.Messages.success(NX.I18n.format('FolderInfo_Delete_Success'));
                   }
                 });
           });
@@ -785,54 +839,6 @@ Ext.define('NX.coreui.controller.ComponentAssetTree', {
     return this.getComponentInfo().componentModel;
   },
 
-  /**
-   * Analyze a component using the AHC service
-   *
-   * @private
-   */
-  analyzeAsset: function(button) {
-    var me = this,
-        componentInfo = me.getComponentInfo(),
-        win,
-        form,
-        formValues,
-        repositoryName,
-        assetId;
-
-    if (componentInfo) {
-      win = button.up('window');
-      form = button.up('form');
-      formValues = form.getForm().getValues();
-      repositoryName = componentInfo.componentModel.get('repositoryName');
-      assetId = form.down('combo[name="asset"]').getValue();
-      NX.direct.ahc_Component.analyzeAsset(repositoryName, assetId, formValues.emailAddress, formValues.password,
-          formValues.proprietaryPackages, formValues.reportLabel, function (response) {
-            if (Ext.isObject(response) && response.success) {
-              win.close();
-              NX.Messages.add({text: NX.I18n.get('ComponentDetails_Analyze_Success'), type: 'success'});
-            }
-          });
-    }
-  },
-
-  /**
-   * When app changes, update the reportName as well
-   */
-  selectedApplicationChanged: function(combo) {
-    var me = this,
-        componentInfo = me.getComponentInfo(),
-        labelField;
-
-    if (componentInfo) {
-      labelField = me.getAnalyzeApplicationWindow().down('textfield[name="reportLabel"]');
-      if (!labelField.isDirty()) {
-        //I am setting the original value so it won't be marked dirty unless user touches it
-        labelField.originalValue = combo.getRawValue();
-        labelField.setValue(combo.getRawValue());
-      }
-    }
-  },
-
   removeNodeFromTree: function(node) {
     var me = this,
         panel = me.getComponentAssetTreePanel(),
