@@ -6,6 +6,10 @@
  * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
  * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
  *
+ * Sonatype Nexus (TM) Open Source Version is distributed with Sencha Ext JS pursuant to a FLOSS Exception agreed upon
+ * between Sonatype, Inc. and Sencha Inc. Sencha Ext JS is licensed under GPL v3 and cannot be redistributed as part of a
+ * closed source work.
+ *
  * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
  * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
  * Eclipse Foundation. All other trademarks are the property of their respective owners.
@@ -57,17 +61,20 @@ Ext.define('NX.coreui.controller.Search', {
     { ref: 'searchResult', selector: 'nx-coreui-searchfeature nx-coreui-search-result-list' },
     { ref: 'componentDetails', selector: 'nx-coreui-searchfeature nx-coreui-component-details' },
     { ref: 'assetList', selector: 'nx-coreui-searchfeature nx-coreui-component-asset-list' },
-    { ref: 'quickSearch', selector: 'nx-header-panel #quicksearch' }
+    { ref: 'quickSearch', selector: 'nx-header-panel #quicksearch' },
+    { ref: 'info', selector: 'nx-coreui-searchfeature #info' },
+    { ref: 'warning', selector: 'nx-coreui-searchfeature #warning' }
   ],
 
+  timedOutMessage: null,
+  limitMessage: null,
+
   /**
    * @override
    */
   init: function() {
     var me = this;
-
     me.callParent();
-
     me.getApplication().getIconController().addIcons({
       'search-default': {
         file: 'magnifier.png',
@@ -88,9 +95,18 @@ Ext.define('NX.coreui.controller.Search', {
       'search-saved': {
         file: 'magnifier.png',
         variants: ['x16', 'x32']
+      },
+      'message-primary': {
+        file: 'information.png',
+        variants: ['x16', 'x32'],
+        preload: true
+      },
+      'message-danger': {
+        file: 'exclamation.png',
+        variants: ['x16', 'x32'],
+        preload: true
       }
     });
-
     me.registerFilter([
       {
         id: 'keyword',
@@ -110,11 +126,9 @@ Ext.define('NX.coreui.controller.Search', {
         readOnly: true
       }
     ], me);
-
     me.getStore('SearchFilter').each(function(model) {
       me.registerFeature(model, me);
     });
-
     me.listen({
       controller: {
         '#Refresh': {
@@ -123,7 +137,8 @@ Ext.define('NX.coreui.controller.Search', {
       },
       component: {
         'nx-coreui-searchfeature nx-coreui-search-result-list': {
-          beforerender: me.onBeforeRender
+          beforerender: me.onBeforeRender,
+          render: me.showHideResponseMessage
         },
         'nx-coreui-searchfeature': {
           afterrender: me.initCriterias
@@ -147,12 +162,13 @@ Ext.define('NX.coreui.controller.Search', {
           search: me.onQuickSearch,
           searchcleared: me.onQuickSearch
         }
+      },
+      store: {
+        '#SearchResult': {
+          load: me.setResponseMessage
+        }
       }
     });
-
-    me.getStore('SearchResult').on('load', function() {
-      me.showHideLimitMessage();
-    });
   },
 
   /**
@@ -258,22 +274,63 @@ Ext.define('NX.coreui.controller.Search', {
 
   /**
    * @private
-   * Show or hide the results limited message.
+   *
+   * Store a message to be displayed along with the store results
    */
-  showHideLimitMessage: function() {
-    var me = this,
-        rawData =  me.getStore('SearchResult').proxy.reader.rawData,
-        info = me.getFeature() ? me.getFeature().down('#info') : null,
-        format = Ext.util.Format.numberRenderer('0,000');
-    if (info) {
-      if (rawData && rawData.limited) {
-        info.setTitle(NX.I18n.format('Search_Results_Limit_Message',
-            format(rawData.total), format(rawData.unlimitedTotal)));
-        info.show();
-      }
-      else {
-        info.hide();
-      }
+  setResponseMessage: function() {
+    var rawData = this.getSearchResultStore().proxy.reader.rawData,
+        searchRequestTimeoutInSeconds = NX.State.getValue('uiSettings', {})['searchRequestTimeout'] ||
+            NX.State.getValue('uiSettings', {})['requestTimeout'] - 5,
+        timedOut = rawData && rawData.timedOut,
+        limited = rawData && rawData.limited,
+        format = Ext.util.Format.numberRenderer('0,000'),
+        learnMore = '<a target="_blank" rel="noopener" href="' + NX.controller.Help.getDocsUrl() + '/Searching+for+Components">' +
+            NX.I18n.get('Search_Results_TimedOut_LearnMore') + ' <i class="fa fa-external-link" /></a>';
+
+    if (timedOut) {
+      this.timedOutMessage = NX.I18n.format('Search_Results_TimedOut_Message', searchRequestTimeoutInSeconds, learnMore);
+    }
+    else {
+      this.timedOutMessage = null;
+    }
+
+    if (limited) {
+      this.limitMessage = NX.I18n.format('Search_Results_Limit_Message', format(rawData.total), format(rawData.unlimitedTotal));
+    }
+    else {
+      this.limitMessage = null;
+    }
+
+    this.showHideResponseMessage();
+  },
+
+  /**
+   * @private
+   *
+   * Show/hide the response messages
+   */
+  showHideResponseMessage: function() {
+    var warning = this.getWarning(),
+        info = this.getInfo();
+
+    if (!warning || !info) {
+      return;
+    }
+
+    if (this.timedOutMessage) {
+      warning.setTitle(this.timedOutMessage);
+      warning.show();
+    }
+    else {
+      warning.hide();
+    }
+
+    if (this.limitMessage) {
+      info.setTitle(this.limitMessage);
+      info.show();
+    }
+    else {
+      info.hide();
     }
   },
 
@@ -363,7 +420,7 @@ Ext.define('NX.coreui.controller.Search', {
       cls: 'more-criteria',
       itemId: 'addButton',
       text: NX.I18n.get('Search_More_Text'),
-      glyph: 'xf055@FontAwesome' /* fa-plus-circle */,
+      iconCls: 'x-fa fa-plus-circle',
       menu: addCriteriaMenu
     });
   },
