@@ -6,6 +6,10 @@
  * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
  * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
  *
+ * Sonatype Nexus (TM) Open Source Version is distributed with Sencha Ext JS pursuant to a FLOSS Exception agreed upon
+ * between Sonatype, Inc. and Sencha Inc. Sencha Ext JS is licensed under GPL v3 and cannot be redistributed as part of a
+ * closed source work.
+ *
  * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
  * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
  * Eclipse Foundation. All other trademarks are the property of their respective owners.
@@ -26,10 +30,10 @@ Ext.define('NX.ext.grid.column.Column', {
    * @override
    */
   toggleSortState: function() {
-    var store = this.up('grid').getStore();
-    if (this.up('grid').allowClearSort && this.isSortable() && this.sortState === 'DESC') {
-      store.sorters.clear();
-      store.load();
+    var view = this.up('grid');
+    if (view && view.allowClearSort && this.isSortable() && this.sortState === 'DESC') {
+      view.getStore().sorters.clear();
+      view.getStore().load();
     }
     else {
       this.callParent();
