@@ -36,7 +36,7 @@ Ext.define('NX.proui.view.tags.TagFeature', {
       nxActions: [{
         xtype: 'button',
         text: NX.I18n.get('TagFeature_FindTaggedComponents_Button'),
-        glyph: 'xf002@FontAwesome' /* fa-search */,
+        iconCls: 'x-fa fa-search',
         action: 'search',
         disabled: false
       }]
