@@ -41,7 +41,7 @@ Ext.define('NX.proui.view.usertoken.UserTokenUser', {
 
           buttonAlign: 'left',
           buttons: [
-            { text: NX.I18n.get('UserToken_UserTokenUser_ResetToken_Button'), action: 'reset', ui: 'nx-primary', glyph: 'xf023@FontAwesome' /* fa-lock */ }
+            { text: NX.I18n.get('UserToken_UserTokenUser_ResetToken_Button'), action: 'reset', ui: 'nx-primary', iconCls: 'x-fa fa-lock' }
           ]
         }
       ]
